#!/usr/bin/env python

import pandas as pd
from matplotlib import pyplot as plt
import seaborn as sns

#codon usage frequency(percentage) of each strain were calculated Codon Usage Generator (http://bioinfo.ie.niigata-u.ac.jp/?Codon%20Usage%20Generator )
#Import a table that summarized the codon usage frequency of each strain.
codon = pd.read_excel('codon_amino_acid_table.xlsx', sheet_name = 'codon_percent')
codon = codon.set_index('Codon')
#drop stop codon from the table 
codon = codon.drop(["UAA", "UAG", "UGA"])

#rename strain name of the column
list(codon.T.index)
before = ['Legionella_cincinnatiensis_NCTC_12438_cds_dna.fasta',
 'Legionella_fallonii_LLAP-10_cds_dna.fasta',
 'Legionella_hackeliae_ATCC_35250_cds_dna.fasta',
 'Legionella_jordanis_NCTC_11533_cds_dna.fasta',
 'Legionella_lansingensis_NCTC_12830_cds_dna.fasta',
 'Legionella_longbeachae_NCTC_11477_cds_dna.fasta',
 'Legionella_micdadei_ATCC_33218_cds_dna.fasta',
 'Legionella_moravica_NCTC_12239_cds_dna.fasta',
 'Legionella_pneumophila subsp. pneumophila_Philadelphia_1_CDC_cds_dna.fasta',
 'Legionella_quateirensis_NCTC_12376_cds_dna.fasta',
 'Legionella_sainthelensi_NCTC_11988_cds_dna.fasta',
 'Legionella_shakespearei_ATCC_49655_cds_dna.fasta',
 'Legionella_sp._TUM19329_cds_dna.fasta',
 'Legionella_tucsonensis_ATCC_49180_cds_dna.fasta',
 'Legionella_wadsworthii_NCTC_11532_cds_dna.fasta',
 'Legionella_worsleiensis_NCTC_12377_cds_dna.fasta',
 'Fluoribacter_bozemanae_NCTC_11368_cds_dna']

after = ['L. cincinnatiensis',
 'L. fallonii',
 'L. hackeliae',
 'L. jordanis',
 'L. lansingensis',
 'L. longbeachae',
 'L. micdadei',
 'L. moravica',
 'L. pneumophila',
 'L. quateirensis',
 'L. sainthelensi',
 'L. shakespearei',
 'TUM19329',
 'L. tucsonensis',
 'L. wadsworthii',
 'L. worsleiensis',
 'L. bozemanae']


rename = dict(zip(before, after))
rename

codon.rename(columns = rename, inplace = True)
codon.head()

#convert amino acid usage frequency table from codon usage table 

#Importing codon and amino acid correspondence list
codon_to_amino_acid =  pd.read_excel('codon_amino_acid_table.xlsx', sheet_name = 'codon_aa')
codon_to_amino_acid.head()
#merge the list with codon table and group by amino acid
amino_acid = pd.merge(codon, codon_to_amino_acid, left_index=True, right_on = "Codon", how = "left")
amino_acid = amino_acid.groupby("Amino acid").sum()
amino_acid.head()

#Create codon heatmap (detail) figure
sns.clustermap(codon.T, standard_scale = 0, figsize = (18, 8))
#save as pdf file
plt.savefig('codon_heatmap_detail.pdf')


#Create codon heatmap figure
sns.clustermap(codon.T, standard_scale = 0, figsize = (6, 5))
#save as pdf file
plt.savefig('codon_heatmap.pdf')

#Create amino acid frequency heatmap figure 
amino_heatmap = sns.clustermap(amino_acid.T, standard_scale = 0, figsize = (6, 5))
#save as pdf file
plt.savefig('aa_heatmap.pdf')

#Relative sinonymous codon usage of L.antarctica TUM19329 and L. fallonii were calculated by Codon Usage Generator (http://bioinfo.ie.niigata-u.ac.jp/?Codon%20Usage%20Generator )
#import table 
RSCU = pd.read_excel('codon_amino_acid_table.xlsx', sheet_name = 'RSCU_table')
RSCU

#sort the table and 
RSCU_sort = RSCU.sort_values("TUM19329_RSCU")
RSCU_sort = RSCU_sort[RSCU_sort["AA"] != "Stop"]
RSCU_sort

#codon(amino acid) figure
plt.figure(figsize = (5, 4), dpi = 300)
plt.plot(RSCU_sort['codon(amino acid)'], RSCU_sort['Lfallonii_RSCU'], marker="o", markersize=1.5, color = "magenta", linestyle = "", label = '$L.fallonii$')
plt.plot(RSCU_sort['codon(amino acid)'], RSCU_sort['TUM19329_RSCU'], marker="v", markersize=1.5, color = "cyan", linestyle = "", 
         label = 'TUM19329$\mathrm{^{T}}$')

#plt.plot(x, y2, marker="v", color = "blue", linestyle = ":")
plt.xticks(rotation = 90, fontsize = 3.5)
plt.yticks(fontsize = 8)
plt.xlabel('Codons of amino acids', fontsize = 10)
plt.ylabel('Relative synonymous codon usage', fontsize = 10)
plt.legend(loc = 'upper left', fontsize = 10)
plt.savefig('RSCU_figure.pdf')
