#!/usr/bin/env python
# coding: utf-8

import pandas as pd
import matplotlib.pyplot as plt

#importing three files downloaded from EzBioCloud Comparative Genomics pipeline
#importing total CDS table of TUM19329 as "df"
df = pd.read_excel("Legionella_sp._TUM19329_CDSs.xlsx")

#TUM19329 specific CDS among 17 Legionella species as "df_unique"
df_unique = pd.read_csv("singleton_strain_specific_CDSs.csv", sep = ',')

#Coregenome among 17 Legionella species in the article as "df_core"
df_core = pd.read_csv("coregenome.csv", sep=",")

#group the total, unique, and core CDS table by column "EggNOG ID" and create a list of the number of each EggNOG ID
total_COG = df["EggNOG ID"].groupby(df["EggNOG ID"]).count().sort_values(ascending=False)
unique_COG = df_unique["EggNog ID"].groupby(df_unique["EggNog ID"]).count().sort_values(ascending=False)
core_COG=df_core["COG Categoty:EggNog ID"].groupby(df_core["COG Categoty:EggNog ID"]).count()

#change the above list to dataframe
total_COG = pd.DataFrame(total_COG)
unique_COG = pd.DataFrame(unique_COG)
core_COG = pd.DataFrame(core_COG)

#rename column name of total COG
total_COG=total_COG.rename(columns = {"EggNOG ID" : "total"})
total_COG.head()

unique_COG=unique_COG.rename(columns = {"EggNog ID" : "unique"})
unique_COG.head()

core_COG=core_COG.rename(columns = {"COG Categoty:EggNog ID" : "core"})
core_COG.head()

#merge
table = pd.merge(total_COG, unique_COG, left_index=True, right_index=True, how="outer" )
table = pd.merge(table, core_COG, left_index= True, right_index= True, how="outer")
table = table.fillna(0)
table.head()

#add shared genes by subtracting the number of each unique and core CDS from the total number of CDS
table["shared"] = table["total"] - table["unique"] - table["core"]
table.head()

#group the table by COG functional category
table["cog_id"] = table.index
table["cog_category"] = table["cog_id"].str.split(":", expand = True)[0]
cog_category_table = table.groupby("cog_category").sum()
cog_category_table.head()

cog_category_table.to_csv("list.csv")

#Genes assigned to multiple COG categories were excluded from the analysis
#The number of genes assigned to multiple COG categories consisted of 1.6% of the COG assigned genes 
#We added a column "cog_category_letter_length" which show the character length of index and excluded letters more than 1.

letter=[]
for i in cog_category_table.index:
    letter_length = len(i)
    letter.append(letter_length)
letter
cog_category_table["cog_category_letter_length"] = letter

#We extracted the character length of index that was 1
cog_category_table =cog_category_table[cog_category_table["cog_category_letter_length"] ==1]
cog_category_table.head()

#create figure
figure_4= cog_category_table[["core", "shared", "unique"]]
figure_4=figure_4.reindex(index = ['D', 'M', 'N', 'O', 'T', 'U', 'V', 'W', 'Y', 'Z', 'A', 'B', 'J', 'K', 'L', 'C', 'E', 'F', 'G', 'H', 'I', 'P', 'Q', 'R', 'S'])
figure_4.plot.bar(stacked = True)
plt.savefig("figure4.pdf")
